@@ -238,13 +238,14 @@ class BaseSlides:
         1. code`slides.build(number, callable)` to create a slide from a `callable(slide)` immediately, e.g. code`lambda s: slides.write(1,2,3)` or as a decorator.
             - Docstring of callable (if any) is parsed as markdown before calling function.
         2. code`with slides.build(number):` creates single slide. Equivalent to code`%%slide number` magic.
-            - Use code`fsep()` from top import or code`Slides.fsep()` to split content into frames.
-            - Use code`for item in fsep.iter(iterable):` block to automatically add frame separator.
-            - Use code`fsep(True)` / code`fsep.iter(...,stack=True)` to join content of frames incrementally.
+            - Use code`PAGE()` from top import or code`Slides.PAGE()` to split content into pages/sub slides.
+            - Use code`for item in PAGE.iter(iterable):` block to automatically add page separator.
+            - Use code`PAGE()` / code`PAGE.iter(...)` to display content on each page incrementally in parts.
+            - Contents displayed by `write` function can be split into parts if `write` is called after `PART()` adjacently.
         3. code`slides.build(number, str, **vars)` creates many slides with markdown content. Equivalent to code`%%slide number -m` magic in case of one slide.
-            - Frames separator is double dashes `--` and slides separator is triple dashes `---`. Same applies to code`Slides.sync_with_file` too.
-            - Use `%++` to join content of frames incrementally.
-            - Markdown `multicol` before `--` creates incremental columns if `%++` is provided.
+            - Page separator is double dashes `--` and slides separator is triple dashes `---`. Same applies to code`Slides.sync_with_file` too.
+            - Use `++` to separted content into parts for incremental display on ites own line with optionally adding content after one space.
+            - Markdown `multicol`/`columns` can be displayed incrementally if `++` is used (alone on line) before these blocks as a trigger.
             - See `slides.xmd.syntax` for extended markdown usage.
             - To debug markdown content, use EOF on its own line to keep editing and clearing errors. Same applies to `Slides.sync_with_file` too.
             - Variables such as \%{var} can be provided in `**vars` (or left during build) and later updated in notebook using `rebuild` method on slide handle or overall slides.
@@ -398,7 +399,7 @@ class BaseSlides:
                    
         with self.build(-1):
             self.write('## Displaying Source Code')
-            self.write('In markdown, the block `md-[before,after,left,right] [-c]` parses and displays source as well.')
+            self.write('In markdown, the block `md-[before,after,var_name]` parses and displays source as well.')
             self.doc(self.code,'Slides', members = True, itself = True).display()
         
         self.build(-1, r'section`//Layout and color["yellow","black"]`Theme` Settings//` toc`### Contents`')
@@ -416,7 +417,7 @@ class BaseSlides:
             
             members = sorted((
                 'AnimationSlider alert bokeh2html bullets esc styled fmt code color details doc '
-                'today error zoomable html iframe image frozen notify plt2html '
+                'today error focus html iframe image frozen notify plt2html '
                 'raw set_dir sig stack table textbox suppress_output suppress_stdout svg vspace'
             ).split())
             self.doc(self, 'Slides', members = members, itself = False).display()
@@ -464,7 +465,7 @@ class BaseSlides:
             )
     
         self.build(-1, """
-        ```md-after -c
+        ```md-src
         stack[(3,7)]`//
         ## Content Styling
         You can **style**{.error} or **color["teal"]`colorize`** your *content*{: style="color:hotpink;"} and *color["hotpink","yellow"]`text`*.
@@ -473,6 +474,7 @@ class BaseSlides:
         || %{self.css_styles}
         //`     
         ```
+        %{src.collapsed}
         """, self=self)
         
         self.build(-1, '''
@@ -499,11 +501,11 @@ class BaseSlides:
         with self.build_() as s:
             self.write("## Adding content on frames incrementally yoffset`0`")
             self.frozen(widget := (code := s.get_source()).as_widget()).display()
-            self.fsep(stack=True) # frozen in above line get oldest metadata for export
-            def highlight_code(slide): widget.value = code.focus_lines(range(slide.indexf + 1)).value
+            # frozen in above line get oldest metadata for export
+            def highlight_code(slide): widget.value = code.focus(range(slide.indexf + 1)).value
             self.on_load(highlight_code)
         
-            for ws, cols in self.fsep.iter(zip([None, (2,3),None], [(0,1),(2,3),(4,5,6,7)])):
+            for ws, cols in self.PART.iter(zip([None, (2,3),None], [(0,1),(2,3),(4,5,6,7)])):
                 cols = [self.html('h1', f"{c}",style="background:var(--bg3-color);margin-block:0.05em !important;") for c in cols]
                 self.write(*cols, widths=ws)
                     
@@ -523,15 +525,13 @@ class BaseSlides:
         with self.build(-1):
             self.write(r'''
             ## Focus on what matters
-            - There is a zoom button on top bar which enables zooming of certain elements. This can be toggled by `Z` key.
-            - Most of supported elements are zoomable by default like images, matplotlib, bokeh, PIL image, altair plotly, dataframe, etc.
-            - You can also enable zooming for an object/widget by wrapping it inside \`Slide.zoomable\` function conveniently.
-            - You can also enable by manully adding `zoom-self`, `zoom-child` classes to an element. To prevent zooming under as `zoom-child` class, use `no-zoom` class.
+            - Most of supported elements can be focused by default like images, matplotlib, bokeh, PIL image, altair plotly, dataframe, etc.
+            - You can also enable focus on an object/widget by wrapping it inside \`Slide.focus\` function conveniently.
+            - You can also enable focus by manully adding `focus-self`, `focus-child` classes to an element. To prevent focus under as `focus-child` class, use `no-focus` class.
             
-            ::: zoom-self block-red
+            ::: focus-self block-red
                 ### Focus on Me 😎
-                - If zoom button is enabled, you can hover here to zoom in this part!
-                - You can also zoom in this part by pressing `Z` key while mouse is over this part.
+                Double click to focus on this block. Click at top right button or double click to exit.
             ''')
 
         with self.build(-1):
