@@ -299,7 +299,7 @@ def style_css(colors, fonts, layout, _root = False):
             'flex-direction':'column !important',
             'align-items': 'center !important' if layout.centered else 'baseline !important', 
             'justify-content': 'flex-start !important', # Aligns the content to the top of box to avoid hiding things
-            'padding' : '16px !important', # don't make 1em to avoid zoom with fonts
+            'padding' : '16px !important', # don't make 1em to avoid change size with fonts
             'padding-bottom': 'var(--paddingBottom, 23px) !important',
             'overflow': 'auto !important' if layout.scroll else 'hidden !important',
             '> .jp-OutputArea': {
@@ -310,8 +310,8 @@ def style_css(colors, fonts, layout, _root = False):
                 'max-width': f'{layout.width}% !important',
                 'box-sizing': 'border-box !important',
                 'overflow': 'auto !important' if layout.scroll else 'hidden !important', # needs here too besides top
-                '@media print': { # For PDF printing of frames, data-hidden set by JS
-                    '> .jp-OutputArea-child[data-hidden], .columns.writer > div[data-hidden]': {
+                '@media print': { # For PDF printing of frames, data-hidden set by JS, first sellectors works for rows too beside top level
+                    '.jp-OutputArea-child[data-hidden], .columns.writer > div[data-hidden]': {
                         ' , *': {'visibility': 'hidden !important',}, 
                     },
                 },
@@ -328,6 +328,31 @@ def style_css(colors, fonts, layout, _root = False):
                     "margin-top": "0 !important", 
                 }
             } if layout.yoffset is not None else {}),# global yoffset, even centered
+            **({'*': {
+                'max-height':'max-content !important',
+                }
+            } if layout._reflow else {}), # clean way to reflow all content
+            '.speaker-notes': {
+                **({} if layout._inotes else {'display':'none !important',}), # hide notes if not choosen to include in print
+                'border-radius':'0.2em !important',
+                'background':'var(--bg2-color) !important',
+                'border':'1px dashed var(--pointer-color) !important',
+                'padding':'0.4em 0.2em 0.2em 0.2em !important',
+                'font-size':'1.5em !important',
+                'position':'relative !important',
+                'margin-top':'0.5em !important',
+                '^::before': {
+                    'content': '"Speaker Notes"',
+                    'font-size':'0.6em !important', # 60% of note size
+                    'position': 'absolute !important',
+                    'top': '-0.8em !important',
+                    'left': '0.5em !important',
+                    'background': 'var(--pointer-color) !important',
+                    'color': 'var(--bg1-color) !important',
+                    'padding': '0 0.5em !important',
+                    'border-radius': '0.2em !important',
+                }, 
+            },
             '.slide-link, .link-button': {
                 'color':'var(--accent-color)',
                 'text-decoration':'none !important',
@@ -485,6 +510,7 @@ def style_css(colors, fonts, layout, _root = False):
         'code': {
             'color': 'var(--fg2-color) !important',
             'font-family': 'var(--jp-code-font-family) !important',
+            '^.dim': {'opacity':'0.3 !important'}, # should work outside block too
         }, # external code tags
         'span.sig': {
             'color': 'var(--accent-color) !important',
@@ -536,7 +562,6 @@ def style_css(colors, fonts, layout, _root = False):
                     'word-break':'break-word', # for breaking words 
                     '^.err, ^.nn, ^.nc' : {'background': 'none !important', 'text-decoration': 'none !important',}, 
                 },
-                '^.code-no-focus': {'opacity':'0.3 !important'},
             },
         },
         '.highlight.numbered code': {
@@ -683,13 +708,14 @@ def style_css(colors, fonts, layout, _root = False):
             'height':'auto',    
         },
         '.click-wrapper': { # PDF/HTML -only clicker at bottom right
-            'position': 'fixed !important',
+            'position': 'absolute !important',
+            '@media print': {'position': 'fixed !important',},
             'right': '16px !important', # space for slide number
             'bottom': '2px !important',
             'width': '110px !important',
             'max-width': '110px !important',
             'height': '21px !important',
-            'display': 'flex !important',
+            'display': 'flex', # no impportant as in print-only display is none
             'z-index': '6 !important',
             'justify-content': 'space-evenly !important',
             '.clicker': {
