@@ -1,18 +1,17 @@
-import sys, os, json, re, math, uuid, textwrap
+import sys, os, json, re, math, uuid, textwrap, warnings
 from contextlib import contextmanager, suppress
 from collections import namedtuple
 from collections.abc import Iterable
 from itertools import zip_longest
 from typing import Union, overload
-from functools import wraps
 from pathlib import Path
 
 from IPython import get_ipython
 from IPython.display import display, clear_output
 
 from .xmd import xmd, esc, fmt, get_main_ns, _matched_vars
-from .writer import hold, write
-from .formatters import bokeh2html, plt2html, plt2image, serializer
+from .writer import hold, write, _DELIMITER
+from .formatters import bokeh2html, plt2html, plt2image, serializer, _delim
 from . import utils
 from . import dashlab
 
@@ -75,7 +74,6 @@ class Singleton(type):
     def __call__(cls, extensions=[], **settings): # I don't know what's magic is here!
         if cls._instance is None:
             cls._instance = super().__call__(extensions=extensions, **settings)
-            cls._instance.fsep = fsep # frame separator is needed to be attached
         else: # reset these settings on previous instance on every call
             xmd.extensions.extend(extensions) 
             cls._instance.settings(**settings)
@@ -757,9 +755,9 @@ class Slides(BaseSlides,metaclass=Singleton):
             ::: note-info
                 Find special syntax to be used in markdown by `Slides.xmd.syntax`.
         ::: note
-            - If Markdown is separated by two dashes (--) on it's own line, multiple frames are created and shown incrementally.
-            - In case of frames, you can add %++ (percent plus plus) in the content to add frames incrementally.
-            - Frames separator (--) just after `multicol` creates incremental columns.
+            - If Markdown is separated by two dashes (--) on it's own line, multiple pages are created in a slide.
+            - You can add ++ (plus plus) in the content staring on new line to add parts which reveal incrementally.
+            - Parts separator (++) just before `multicol`/`columns` creates incremental columns and rows.
             - Use `%%slide -1` to enable auto slide numbering. Other cell code is preserved.
             - 
 
@@ -795,16 +793,17 @@ class Slides(BaseSlides,metaclass=Singleton):
                 for idx, (frm, prm) in enumerate(zip_longest(frames, prames, fillvalue='')):
                     if '%++' in frm: # remove %++ from here, but stays in source above for user reference
                         frm = frm.replace('%++','').strip() # remove that empty line too
-                        s.stack_frames(True)
+                        self.this._split_frames = False
+                        warnings.warn("`%++` is deprecated, use `++` explicitly on each part separation!", DeprecationWarning, stacklevel=2)
                     
                     self.xmd(frm, returns = False) # parse and display content
                     
                     if len(frames) > 1:
-                        self.fsep() # should not be before, needs at least one thing there
+                        self.PAGE() # legacy will change it to part or page based on context
                     
                     if prm != frm: 
                         edit_idx = idx
-                        if self.this.stacked and ('```multicol' in frm): # show all columns if edit is inside multicol
+                        if not self.this._split_frames and ('```multicol' in frm): # show all columns if edit is inside multicol
                             edit_idx += (len(re.findall(r'^\+\+\+$|^\+\+\+\s+$',frm, flags=re.DOTALL | re.MULTILINE)) + 1)
             
             s.first_frame() # be at start first
@@ -904,54 +903,75 @@ class Slides(BaseSlides,metaclass=Singleton):
 
         return tuple(filter(lambda s: s.number in slide_numbers, self._slides_dict.values())) 
     
-def _ensure_slides_init(func):
-    @wraps(func)
-    def inner(*args,**kwargs):
-        if Slides.instance() is None:
-            raise RuntimeWarning("Slides was never initialized!")
-        return func(*args, **kwargs)
-    return inner
-
-
-class fsep:
-    """Frame separator! If it is just after `write` command, columns are incremented too.
-    You can import it on top level or use as `Slides.fsep`.
-
-    - Use `fsep()` to split code into frames. In markdown slides, use two dashes --.
-    - Use `fsep.iter(iterable)` to split after each item in iterable automatically.
-    - Setting `stack=True` in `fsep` or `fsep.iter` once under a slide to show frames incrementally. 
-        In markdown slides, use %++. The last called value of stack overrides any previous value.
-    - Content before first frame separator is added on all frames. This helps adding same title once.
-    """
-    _app_ins = Slides.instance # need to be called as it would not be defined initially
     
-    @_ensure_slides_init
-    def __init__(self, stack=None):
-        app = self._app_ins()
-        app.verify_running("Cant use fsep in a capture context other than slides!")
-        app.this._widget.add_class("base") # this is needed to distinguisg clones during printing
+    class fsep:
+        """::: note-warning
+            Legacy frame seperator for backward compatibility and will be deprecated. It only creates
+            pages or parts based on context. New delimiter classes `Slides.PAGE` and `Slides.PART` are 
+            very flexible to create mixed pages and parts and also allow more control over splitting behavior.
         
-        sep = app.html('')
-        if not hasattr(app.this, '_fsep'): 
-            sep = sep.as_widget() # first separator must be a widget
-            app.this._fsep = sep # this is used to change frames dynamically
-        
-        display(sep, metadata={"FSEP": "","skip-export":"no need in export"})
-        
-        if stack in (True, False):
-            app.this.stack_frames(stack)
-        elif stack is not None:
-            raise ValueError(f"stack should be set True or False or left as None for default behavior, got {type(stack)}")
+        Frame separator! If it is just after `write` command, columns are incremented too.
+        You can import it on top level or use as `Slides.fsep`.
 
-    @classmethod
-    @_ensure_slides_init
-    def iter(cls, iterable, stack=None):
-        "Loop over iterable. Frame separator is add before each item and at end of the loop."
-        cls._app_ins().verify_running()
-        if not isinstance(iterable, Iterable) or isinstance(iterable, (str, bytes, dict)):
-            raise TypeError(f"iterable should be a list-like object, got {type(iterable)}")
+        - Use `fsep()` to split code into frames. In markdown slides, use two dashes --.
+        - Use `fsep.iter(iterable)` to split after each item in iterable automatically.
+        - Setting `stack=True` in `fsep` or `fsep.iter` once under a slide to show frames incrementally. 
+            In markdown slides, use %++. The last called value of stack overrides any previous value.
+        - Content before first frame separator is added on all frames. This helps adding same title once.
+        """
+        @staticmethod
+        def _app_ins(): return Slides.instance()
         
-        for item in iterable:
-            cls(stack) # put one separator before
-            yield item
-        cls(stack) # put after all done to keep block separated
+        def __init__(self, stack=None):
+            app = self._app_ins()
+            app.verify_running("Cant use fsep in a capture context other than slides!")
+            _type = "" if stack is None else "PART" if stack else "PAGE"
+            display(_delim(_type))  # display delimiter
+            app.this._fsep_legacy = True  # for backward compatibility
+
+            if stack in (True, False):
+                app.this._split_frames = not stack
+            elif stack is not None:
+                raise ValueError(f"stack should be set True or False or left as None for default behavior, got {type(stack)}")
+            warnings.warn("Legacy fsep() detected, converted to new delimiter internally. Consider updating your code to use PAGE and PART explicitly!", DeprecationWarning, stacklevel=2)
+
+        @classmethod
+        def iter(cls, iterable, stack=None):
+            "Loop over iterable. Frame separator is add before each item and at end of the loop."
+            cls._app_ins().verify_running()
+            if not isinstance(iterable, Iterable) or isinstance(iterable, (str, bytes, dict)):
+                raise TypeError(f"iterable should be a list-like object, got {type(iterable)}")
+
+            for item in iterable:
+                cls(stack) # put one separator before
+                yield item
+            cls(stack) # put after all done to keep block separated
+    
+    class PAGE(_DELIMITER):
+        """Page delimiter! Use `Slides.PAGE()` or import at top level to create a new page in slide.
+        In markdown slides, use two dashes -- on its own line.
+        
+        - Content before first PAGE delimiter is added on all pages. This helps adding same title once.
+        - If there is no content after PAGE, a page with header content is created.
+        - Last empty PAGE delimiter is ignored.
+        - Use code`PAGE.iter(iterable)` to create multiple pages from iterable automatically.
+        """
+        _type = "PAGE"
+
+    class PART(_DELIMITER):
+        """Part delimiter! Use `Slides.PART()` or import at top level to create a new part in slide/page.
+        In markdown slides, use two plus signs `++` on its own line, optionally add content right after `++ `.
+        
+        - Adjacent `PART` delemiters are ignored, so no empty parts are created.
+        - A call `PART()` before `write` command adds parts inside columns and rows. 
+          See `write` command for more details. This is equivalent to adding `++` before `columns/multicol` block in markdown.
+        - A call `PART(*contents)` adds a part with given contents right away and adds a separator after it.
+        - Use code`PART.iter(iterable)` to create multiple parts from iterable automatically.
+        - Last empty PART delimiter is ignored on slide/page.
+        """
+        _type = "PART"
+        
+        def __init__(self, *contents, css_class=None):
+            super().__init__()
+            write([contents], css_class=css_class) # do not let write add extra delimiter in contents
+            display(_delim(self._type)) # separtor after content is important
\ No newline at end of file
