@@ -4,11 +4,13 @@ Main write functions to add content to slides
 
 __all__ = ['write']
 
+from collections.abc import Iterable
+from itertools import chain
 from IPython.display import display as display
 from IPython.utils.capture import CapturedIO
 
-from .formatters import ipw, XTML, RichOutput, _Output, serializer, htmlize, _inline_style, toc_from_meta
-from .xmd import fmt, xmd, capture_content
+from .formatters import ipw, XTML, RichOutput, _Output, serializer, htmlize, _inline_style, toc_from_meta, _delim
+from .xmd import fmt, xmd, capture_content, get_slides_instance
 
 
 class hold:
@@ -27,14 +29,23 @@ class hold:
 
     def display(self):
         self.__call__()
-
-class CustomDisplay:
-    "Use this to create custom display types for object."
-    def _ipython_display_(self):
-        self.display()
     
-    def display(self):
-        raise NotImplementedError("display method must be implemented in subclass")
+class _DELIMITER:
+    "Internal class to create page/part delimiters."
+    _type: str = None  # to be set in subclass
+    def __init__(self):
+        display(_delim(self._type))
+        
+    @classmethod
+    def iter(cls, iterable):
+        "Loop over given iterable by adding a separator before each item and at end of the loop."
+        if not isinstance(iterable, Iterable) or isinstance(iterable, (str, bytes, dict)):
+            raise TypeError(f"iterable should be a list-like object, got {type(iterable)}")
+        
+        for item in iterable:
+            cls() # put one separator before
+            yield item
+        cls() # put after all done to keep block separated
     
 
 def _fmt_html(output):
@@ -51,6 +62,7 @@ def _fmt_html(output):
 class Writer(ipw.HBox):
     _in_write = False
     def __init__(self, *objs, widths = None, css_class = None):
+        self._parts = () # to store part positions
         if self.__class__._in_write and len(objs) > 1: # Like from delayed lambda function
             raise RuntimeError("Trying to write inside a writer!")
         
@@ -66,15 +78,15 @@ class Writer(ipw.HBox):
         finally:
             self.__class__._in_write = False
 
-        if len(objs) == 1:
-            if isinstance(css_class, str):
-                out = _Output(_dom_classes = css_class.split())
-                with out:
-                    display(*self._cols[0]['outputs'])
-                display(out, metadata={'UPDATE', out._model_id}) # For auto refresh
-            else:
-                display(*self._cols[0]['outputs']) 
-        elif len(objs) > 1:
+        if len(objs) == 1 and not isinstance(css_class, str):
+            # css_class still need to make all items in single block, without it just flatten display
+            rows = self._cols[0]['outputs']
+            if len(rows) == 1:
+                display(*rows) # Just display single output directly
+            elif len(rows) > 1:
+                display(rows[0], metadata={"FLATCOL": len(rows)})  # First output with FLATCOL metadata to indicate for frames
+                display(*rows[1:]) # Just display rest of rows directly
+        elif len(objs) >= 1: # avoid empty write
             self.children = [_Output(layout = ipw.Layout(width = c['width'],overflow='auto',height='auto')) for c in self._cols]
             display(self, metadata=self.metadata) # Just display it with ID
             self.update_display() # show content on widgets
@@ -104,25 +116,40 @@ class Writer(ipw.HBox):
         
         widths = [f'{w:.3f}%' for w in widths]
         cols = [{'width':w,'outputs':_c if isinstance(_c,(list,tuple)) else [_c]} for w,_c in zip(widths,objs)]
+        parts, rowsep = [], _delim("ROW")  # row delimiter
         for i, col in enumerate(cols):
+            rows = chain(*(
+                (*obj, rowsep) if isinstance(obj, (list, tuple)) # nested rows as single group
+                else (obj, rowsep)  # each object as single row
+                for obj in col['outputs']
+            ))
             with capture_content() as cap:
-                for c in col['outputs']:
-                    if isinstance(c,(fmt, RichOutput, CustomDisplay, ipw.DOMWidget)):
+                for c in rows:
+                    if isinstance(c,(fmt, RichOutput, ipw.DOMWidget)):
                         display(c)
                     elif isinstance(c, CapturedIO):
                         c.show() # Display captured outputs, all of them
                     elif isinstance(c,str):
                         xmd(c, returns = False)
                     elif isinstance(c, hold):
-                        _ = c() # If c is hold, call it and it will dispatch whatever is inside, ignore return value
+                        c() # If c is hold, call it and it will dispatch whatever is inside, ignore return value
+                    elif hasattr(c, '_ipython_display_') and callable(c._ipython_display_):
+                        c._ipython_display_() # IPython display protocol takes precedence, but we need some cases handled before it
                     else:
                         display(XTML(htmlize(c)))
             
             if cap.stderr:
                 raise RuntimeError(f'Error in column {i+1}:\n{cap.stderr}')
             
-            cols[i]['outputs'] = cap.outputs
+            cols[i]['outputs'] = cap.outputs[:-1]  # remove last rowsep output
             
+            for r, out in enumerate(cols[i]['outputs']):
+                meta = getattr(out, 'metadata', {})
+                if isinstance(meta, dict) and meta.get('DELIM','') == 'ROW':
+                    parts.append({"col": i, "row": r}) # mark row positions
+            parts.append({"col": i}) # only columns incremented after rows done inside
+        
+        self._parts = tuple(parts) # make it immutable
         return cols
     
     def update_display(self):
@@ -134,23 +161,35 @@ class Writer(ipw.HBox):
             else:
                 out.update_display()
     
-    def fmt_html(self, _pad_from=None):
-        "Make HTML representation of columns that is required for exporting slides to other formats."
+    def fmt_html(self, visible_upto=None):
+        "Make HTML representation of columns for exporting slides to other formats."
         cols = []
+        col_idx = (visible_upto or {}).get("col", float('inf')) 
         for i, col in enumerate(self._cols):
-            content = ''
-            if (_pad_from is None) or (isinstance(_pad_from, int) and (i < _pad_from)): # to make frames
-                content += '\n'.join(map(_fmt_html, col['outputs']))
+            if i > col_idx: # Entire column is hidden
+                content = '\n'.join(map(_fmt_html, col['outputs']))
+                cols.append(f'<div style="width:{col["width"]};overflow:auto;height:auto;visibility:hidden">{content}</div>')
+            elif i < col_idx: # Entire column is visible
+                content = '\n'.join(map(_fmt_html, col['outputs']))
+                cols.append(f'<div style="width:{col["width"]};overflow:auto;height:auto">{content}</div>')
+            else: # Current column, check rows
+                rows = []
+                row_idx = (visible_upto or {}).get("row", float('inf'))
+                for r, output in enumerate(col['outputs']):
+                    if r <= row_idx:
+                        rows.append(_fmt_html(output))
+                    else:
+                        rows.append(f'<div style="visibility:hidden;">{_fmt_html(output)}</div>')
                 
-            cols.append(f'<div style="width:{col["width"]};overflow:auto;height:auto">{content}</div>')
-        
-        css_class = ' '.join(self._dom_classes) # handle custom classes in blocks as well
+                cols.append(f'<div style="width:{col["width"]};overflow:auto;height:auto">{"".join(rows)}</div>')
+                
+        css_class = ' '.join(self._dom_classes)
         return f'<div class="{css_class}" {_inline_style(self)}>{"".join(cols)}</div>'
-    
-    
+
+
 def write(*objs,widths = None, css_class=None):
     """
-    Write `objs` to slides in columns. To create rows in a column, wrap objects in a list or tuple.      
+    Write `objs` to slides in columns. To create rows in a column, wrap objects in a list or tuple.   
     You can optionally specify `widths` as a list of percentages for each column. 
     `css_class` can have multiple classes separated by space, works only for multiple columns.
          
@@ -178,5 +217,18 @@ def write(*objs,widths = None, css_class=None):
         - You can use code`display(obj, metadata = {'text/html': 'html repr by user'})` for any object to display object as it is and export its HTML representation in metadata.
         - You can add mini columns inside a column by markdown syntax or ` Slides.stack `, but content type is limited in that case.
         - In markdown `multicol/columns` block syntax is similar to `write` command if `+++` separartor is used there.
+    
+    ::: tip
+        To make a group of rows as single item visually for incremental display purpose, wrap them in a nested list/tuple.
+        A single column is flattened up to 2 levels, so `[[obj1], row2, [item1, item2]]` will be displayed as 3 rows.
+        
+        **Incremental display** is triggered only when you place `Slides.PART()` delimiter **before** the `write` command:
+        
+        ```python
+        slides.PART()  # Trigger incremental display, equivalent to ++ before `multicol/columns` in markdown
+        slides.write([row1, [item1, item2], row3], column2)  # Shows rows one by one (item1 and item2 together), then column2
+        slides.PART()  # Another trigger for next write
+        slides.write([row1, row2]) # Shows both rows incrementally , no additional columns here
+        ``` 
     """
     Writer(*objs,widths = widths, css_class=css_class) # Displays itself
